# <TOPIC_TITLE> - Content Draft

> Generated: <YYYY-MM-DD HH:MM>
> Source Material: outputs/01_draft.jsonl

---

## Collected Viewpoints

### Viewpoint Category A: <CATEGORY_LABEL>

- @<USERNAME_1>: "<TWEET_CONTENT_QUOTE>"
  - Source: <REAL_TWEET_URL>
  - scroll_to: "<UNIQUE_TEXT_FRAGMENT>"

- @<USERNAME_2>: "<TWEET_CONTENT_QUOTE>"
  - Source: <REAL_TWEET_URL>
  - scroll_to: "<UNIQUE_TEXT_FRAGMENT>"

### Viewpoint Category B: <CATEGORY_LABEL>

- @<USERNAME_3>: "<TWEET_CONTENT_QUOTE>"
  - Source: <REAL_TWEET_URL>
  - scroll_to: "<UNIQUE_TEXT_FRAGMENT>"

### Viewpoint Category C: <CATEGORY_LABEL>

- @<USERNAME_4>: "<TWEET_CONTENT_QUOTE>"
  - Source: <REAL_TWEET_URL>
  - scroll_to: "<UNIQUE_TEXT_FRAGMENT>"

---

## My Commentary

<HOST_COMMENTARY_AFTER_DISCUSSION>

---

## Material Index (For Subsequent Recording)

| # | Author | URL | scroll_to_text | Type |
|---|--------|-----|----------------|------|
| 1 | @<USERNAME> | <REAL_URL> | "<TEXT_FRAGMENT>" | tweet/comment |
| 2 | @<USERNAME> | <REAL_URL> | "<TEXT_FRAGMENT>" | tweet/comment |

---

**Notes**:
- All URLs must be valid and accessible links
- scroll_to_text is used for element positioning during recording
- Category labels should concisely summarize the core stance of each viewpoint
